from v4_proto.cosmos.autocli.v1 import options_pb2 as _options_pb2
from v4_proto.cosmos.query.v1 import query_pb2 as _query_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AppOptionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AppOptionsResponse(_message.Message):
    __slots__ = ("module_options",)
    class ModuleOptionsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _options_pb2.ModuleOptions
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_options_pb2.ModuleOptions, _Mapping]] = ...) -> None: ...
    MODULE_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    module_options: _containers.MessageMap[str, _options_pb2.ModuleOptions]
    def __init__(self, module_options: _Optional[_Mapping[str, _options_pb2.ModuleOptions]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LegacyAminoPubKey(_message.Message):
    __slots__ = ("threshold", "public_keys")
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    threshold: int
    public_keys: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, threshold: _Optional[int] = ..., public_keys: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.params.v1beta1 import params_pb2 as _params_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ("subspace", "key")
    SUBSPACE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    subspace: str
    key: str
    def __init__(self, subspace: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("param",)
    PARAM_FIELD_NUMBER: _ClassVar[int]
    param: _params_pb2.ParamChange
    def __init__(self, param: _Optional[_Union[_params_pb2.ParamChange, _Mapping]] = ...) -> None: ...

class QuerySubspacesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QuerySubspacesResponse(_message.Message):
    __slots__ = ("subspaces",)
    SUBSPACES_FIELD_NUMBER: _ClassVar[int]
    subspaces: _containers.RepeatedCompositeFieldContainer[Subspace]
    def __init__(self, subspaces: _Optional[_Iterable[_Union[Subspace, _Mapping]]] = ...) -> None: ...

class Subspace(_message.Message):
    __slots__ = ("subspace", "keys")
    SUBSPACE_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    subspace: str
    keys: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, subspace: _Optional[str] = ..., keys: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/ratelimit/limit_params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)dydxprotocol/ratelimit/limit_params.proto\x12\x16\x64ydxprotocol.ratelimit\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"U\n\x0bLimitParams\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x37\n\x08limiters\x18\x02 \x03(\x0b\x32\x1f.dydxprotocol.ratelimit.LimiterB\x04\xc8\xde\x1f\x00\"\xbc\x01\n\x07Limiter\x12\x33\n\x06period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x62\n\x10\x62\x61seline_minimum\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12\x18\n\x10\x62\x61seline_tvl_ppm\x18\x04 \x01(\rB=Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.ratelimit.limit_params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/dydxprotocol/v4-chain/protocol/x/ratelimit/types'
  _globals['_LIMITPARAMS'].fields_by_name['limiters']._loaded_options = None
  _globals['_LIMITPARAMS'].fields_by_name['limiters']._serialized_options = b'\310\336\037\000'
  _globals['_LIMITER'].fields_by_name['period']._loaded_options = None
  _globals['_LIMITER'].fields_by_name['period']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_LIMITER'].fields_by_name['baseline_minimum']._loaded_options = None
  _globals['_LIMITER'].fields_by_name['baseline_minimum']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIMITPARAMS']._serialized_start=123
  _globals['_LIMITPARAMS']._serialized_end=208
  _globals['_LIMITER']._serialized_start=211
  _globals['_LIMITER']._serialized_end=399
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as _block_rate_limit_config_pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as _clob_pair_pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as _equity_tier_limit_config_pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as _liquidations_config_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("clob_pairs", "liquidations_config", "block_rate_limit_config", "equity_tier_limit_config")
    CLOB_PAIRS_FIELD_NUMBER: _ClassVar[int]
    LIQUIDATIONS_CONFIG_FIELD_NUMBER: _ClassVar[int]
    BLOCK_RATE_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    EQUITY_TIER_LIMIT_CONFIG_FIELD_NUMBER: _ClassVar[int]
    clob_pairs: _containers.RepeatedCompositeFieldContainer[_clob_pair_pb2.ClobPair]
    liquidations_config: _liquidations_config_pb2.LiquidationsConfig
    block_rate_limit_config: _block_rate_limit_config_pb2.BlockRateLimitConfiguration
    equity_tier_limit_config: _equity_tier_limit_config_pb2.EquityTierLimitConfiguration
    def __init__(self, clob_pairs: _Optional[_Iterable[_Union[_clob_pair_pb2.ClobPair, _Mapping]]] = ..., liquidations_config: _Optional[_Union[_liquidations_config_pb2.LiquidationsConfig, _Mapping]] = ..., block_rate_limit_config: _Optional[_Union[_block_rate_limit_config_pb2.BlockRateLimitConfiguration, _Mapping]] = ..., equity_tier_limit_config: _Optional[_Union[_equity_tier_limit_config_pb2.EquityTierLimitConfiguration, _Mapping]] = ...) -> None: ...



from v4_proto.tendermint.abci import types_pb2 as _types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StoreKVPair(_message.Message):
    __slots__ = ("store_key", "delete", "key", "value")
    STORE_KEY_FIELD_NUMBER: _ClassVar[int]
    DELETE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    store_key: str
    delete: bool
    key: bytes
    value: bytes
    def __init__(self, store_key: _Optional[str] = ..., delete: bool = ..., key: _Optional[bytes] = ..., value: _Optional[bytes] = ...) -> None: ...

class BlockMetadata(_message.Message):
    __slots__ = ("response_commit", "request_finalize_block", "response_finalize_block")
    RESPONSE_COMMIT_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FINALIZE_BLOCK_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_FINALIZE_BLOCK_FIELD_NUMBER: _ClassVar[int]
    response_commit: _types_pb2.ResponseCommit
    request_finalize_block: _types_pb2.RequestFinalizeBlock
    response_finalize_block: _types_pb2.ResponseFinalizeBlock
    def __init__(self, response_commit: _Optional[_Union[_types_pb2.ResponseCommit, _Mapping]] = ..., request_finalize_block: _Optional[_Union[_types_pb2.RequestFinalizeBlock, _Mapping]] = ..., response_finalize_block: _Optional[_Union[_types_pb2.ResponseFinalizeBlock, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.clob import block_rate_limit_config_pb2 as dydxprotocol_dot_clob_dot_block__rate__limit__config__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2
from v4_proto.dydxprotocol.clob import equity_tier_limit_config_pb2 as dydxprotocol_dot_clob_dot_equity__tier__limit__config__pb2
from v4_proto.dydxprotocol.clob import order_pb2 as dydxprotocol_dot_clob_dot_order__pb2
from v4_proto.dydxprotocol.clob import matches_pb2 as dydxprotocol_dot_clob_dot_matches__pb2
from v4_proto.dydxprotocol.clob import liquidations_config_pb2 as dydxprotocol_dot_clob_dot_liquidations__config__pb2
from v4_proto.dydxprotocol.clob import mev_pb2 as dydxprotocol_dot_clob_dot_mev__pb2
from v4_proto.dydxprotocol.indexer.off_chain_updates import off_chain_updates_pb2 as dydxprotocol_dot_indexer_dot_off__chain__updates_dot_off__chain__updates__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/clob/query.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a/dydxprotocol/clob/block_rate_limit_config.proto\x1a!dydxprotocol/clob/clob_pair.proto\x1a\x30\x64ydxprotocol/clob/equity_tier_limit_config.proto\x1a\x1d\x64ydxprotocol/clob/order.proto\x1a\x1f\x64ydxprotocol/clob/matches.proto\x1a+dydxprotocol/clob/liquidations_config.proto\x1a\x1b\x64ydxprotocol/clob/mev.proto\x1a>dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto\"%\n\x17QueryGetClobPairRequest\x12\n\n\x02id\x18\x01 \x01(\r\"M\n\x15QueryClobPairResponse\x12\x34\n\tclob_pair\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\"U\n\x17QueryAllClobPairRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x18QueryClobPairAllResponse\x12\x34\n\tclob_pair\x18\x01 \x03(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xb1\x01\n\x1fMevNodeToNodeCalculationRequest\x12\x46\n\x16\x62lock_proposer_matches\x18\x01 \x01(\x0b\x32&.dydxprotocol.clob.ValidatorMevMatches\x12\x46\n\x15validator_mev_metrics\x18\x02 \x01(\x0b\x32\'.dydxprotocol.clob.MevNodeToNodeMetrics\"\xcc\x01\n MevNodeToNodeCalculationResponse\x12^\n\x07results\x18\x01 \x03(\x0b\x32G.dydxprotocol.clob.MevNodeToNodeCalculationResponse.MevAndVolumePerClobB\x04\xc8\xde\x1f\x00\x1aH\n\x13MevAndVolumePerClob\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12\x0b\n\x03mev\x18\x02 \x01(\x02\x12\x0e\n\x06volume\x18\x03 \x01(\x04\"*\n(QueryEquityTierLimitConfigurationRequest\"\x84\x01\n)QueryEquityTierLimitConfigurationResponse\x12W\n\x18\x65quity_tier_limit_config\x18\x01 \x01(\x0b\x32/.dydxprotocol.clob.EquityTierLimitConfigurationB\x04\xc8\xde\x1f\x00\")\n\'QueryBlockRateLimitConfigurationRequest\"\x81\x01\n(QueryBlockRateLimitConfigurationResponse\x12U\n\x17\x62lock_rate_limit_config\x18\x01 \x01(\x0b\x32..dydxprotocol.clob.BlockRateLimitConfigurationB\x04\xc8\xde\x1f\x00\"O\n\x19QueryStatefulOrderRequest\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"\x8e\x01\n\x1aQueryStatefulOrderResponse\x12H\n\x0forder_placement\x18\x01 \x01(\x0b\x32).dydxprotocol.clob.LongTermOrderPlacementB\x04\xc8\xde\x1f\x00\x12\x13\n\x0b\x66ill_amount\x18\x02 \x01(\x04\x12\x11\n\ttriggered\x18\x03 \x01(\x08\"\'\n%QueryLiquidationsConfigurationRequest\"r\n&QueryLiquidationsConfigurationResponse\x12H\n\x13liquidations_config\x18\x01 \x01(\x0b\x32%.dydxprotocol.clob.LiquidationsConfigB\x04\xc8\xde\x1f\x00\"5\n\x1dStreamOrderbookUpdatesRequest\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x03(\r\"\x81\x01\n\x1eStreamOrderbookUpdatesResponse\x12\x36\n\x07updates\x18\x01 \x03(\x0b\x32\x1f.dydxprotocol.clob.StreamUpdateB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x02 \x01(\r\x12\x11\n\texec_mode\x18\x03 \x01(\r\"\xa4\x01\n\x0cStreamUpdate\x12\x44\n\x10orderbook_update\x18\x01 \x01(\x0b\x32(.dydxprotocol.clob.StreamOrderbookUpdateH\x00\x12<\n\norder_fill\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.StreamOrderbookFillH\x00\x42\x10\n\x0eupdate_message\"z\n\x15StreamOrderbookUpdate\x12O\n\x07updates\x18\x01 \x03(\x0b\x32\x38.dydxprotocol.indexer.off_chain_updates.OffChainUpdateV1B\x04\xc8\xde\x1f\x00\x12\x10\n\x08snapshot\x18\x02 \x01(\x08\"\x93\x01\n\x13StreamOrderbookFill\x12\x30\n\nclob_match\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.clob.ClobMatch\x12.\n\x06orders\x18\x02 \x03(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x1a\n\x0c\x66ill_amounts\x18\x03 \x03(\x04\x42\x04\xc8\xde\x1f\x00\x32\x9e\n\n\x05Query\x12\x8b\x01\n\x08\x43lobPair\x12*.dydxprotocol.clob.QueryGetClobPairRequest\x1a(.dydxprotocol.clob.QueryClobPairResponse\")\x82\xd3\xe4\x93\x02#\x12!/dydxprotocol/clob/clob_pair/{id}\x12\x8c\x01\n\x0b\x43lobPairAll\x12*.dydxprotocol.clob.QueryAllClobPairRequest\x1a+.dydxprotocol.clob.QueryClobPairAllResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/dydxprotocol/clob/clob_pair\x12\xbf\x01\n\x18MevNodeToNodeCalculation\x12\x32.dydxprotocol.clob.MevNodeToNodeCalculationRequest\x1a\x33.dydxprotocol.clob.MevNodeToNodeCalculationResponse\":\x82\xd3\xe4\x93\x02\x34\"//dydxprotocol/clob/mev_node_to_node_calculation:\x01*\x12\xc1\x01\n\x1c\x45quityTierLimitConfiguration\x12;.dydxprotocol.clob.QueryEquityTierLimitConfigurationRequest\x1a<.dydxprotocol.clob.QueryEquityTierLimitConfigurationResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/dydxprotocol/clob/equity_tier\x12\xbd\x01\n\x1b\x42lockRateLimitConfiguration\x12:.dydxprotocol.clob.QueryBlockRateLimitConfigurationRequest\x1a;.dydxprotocol.clob.QueryBlockRateLimitConfigurationResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/dydxprotocol/clob/block_rate\x12\xc0\x01\n\x19LiquidationsConfiguration\x12\x38.dydxprotocol.clob.QueryLiquidationsConfigurationRequest\x1a\x39.dydxprotocol.clob.QueryLiquidationsConfigurationResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/clob/liquidations_config\x12n\n\rStatefulOrder\x12,.dydxprotocol.clob.QueryStatefulOrderRequest\x1a-.dydxprotocol.clob.QueryStatefulOrderResponse\"\x00\x12\x7f\n\x16StreamOrderbookUpdates\x12\x30.dydxprotocol.clob.StreamOrderbookUpdatesRequest\x1a\x31.dydxprotocol.clob.StreamOrderbookUpdatesResponse0\x01\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_QUERYCLOBPAIRRESPONSE'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_QUERYCLOBPAIRRESPONSE'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCLOBPAIRALLRESPONSE'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_QUERYCLOBPAIRALLRESPONSE'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_MEVNODETONODECALCULATIONRESPONSE'].fields_by_name['results']._loaded_options = None
  _globals['_MEVNODETONODECALCULATIONRESPONSE'].fields_by_name['results']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE'].fields_by_name['equity_tier_limit_config']._loaded_options = None
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE'].fields_by_name['equity_tier_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE'].fields_by_name['block_rate_limit_config']._loaded_options = None
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE'].fields_by_name['block_rate_limit_config']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSTATEFULORDERREQUEST'].fields_by_name['order_id']._loaded_options = None
  _globals['_QUERYSTATEFULORDERREQUEST'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSTATEFULORDERRESPONSE'].fields_by_name['order_placement']._loaded_options = None
  _globals['_QUERYSTATEFULORDERRESPONSE'].fields_by_name['order_placement']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE'].fields_by_name['liquidations_config']._loaded_options = None
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE'].fields_by_name['liquidations_config']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKUPDATESRESPONSE'].fields_by_name['updates']._loaded_options = None
  _globals['_STREAMORDERBOOKUPDATESRESPONSE'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKUPDATE'].fields_by_name['updates']._loaded_options = None
  _globals['_STREAMORDERBOOKUPDATE'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['orders']._loaded_options = None
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['orders']._serialized_options = b'\310\336\037\000'
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['fill_amounts']._loaded_options = None
  _globals['_STREAMORDERBOOKFILL'].fields_by_name['fill_amounts']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['ClobPair']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClobPair']._serialized_options = b'\202\323\344\223\002#\022!/dydxprotocol/clob/clob_pair/{id}'
  _globals['_QUERY'].methods_by_name['ClobPairAll']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClobPairAll']._serialized_options = b'\202\323\344\223\002\036\022\034/dydxprotocol/clob/clob_pair'
  _globals['_QUERY'].methods_by_name['MevNodeToNodeCalculation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MevNodeToNodeCalculation']._serialized_options = b'\202\323\344\223\0024\"//dydxprotocol/clob/mev_node_to_node_calculation:\001*'
  _globals['_QUERY'].methods_by_name['EquityTierLimitConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EquityTierLimitConfiguration']._serialized_options = b'\202\323\344\223\002 \022\036/dydxprotocol/clob/equity_tier'
  _globals['_QUERY'].methods_by_name['BlockRateLimitConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BlockRateLimitConfiguration']._serialized_options = b'\202\323\344\223\002\037\022\035/dydxprotocol/clob/block_rate'
  _globals['_QUERY'].methods_by_name['LiquidationsConfiguration']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LiquidationsConfiguration']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/clob/liquidations_config'
  _globals['_QUERYGETCLOBPAIRREQUEST']._serialized_start=484
  _globals['_QUERYGETCLOBPAIRREQUEST']._serialized_end=521
  _globals['_QUERYCLOBPAIRRESPONSE']._serialized_start=523
  _globals['_QUERYCLOBPAIRRESPONSE']._serialized_end=600
  _globals['_QUERYALLCLOBPAIRREQUEST']._serialized_start=602
  _globals['_QUERYALLCLOBPAIRREQUEST']._serialized_end=687
  _globals['_QUERYCLOBPAIRALLRESPONSE']._serialized_start=690
  _globals['_QUERYCLOBPAIRALLRESPONSE']._serialized_end=831
  _globals['_MEVNODETONODECALCULATIONREQUEST']._serialized_start=834
  _globals['_MEVNODETONODECALCULATIONREQUEST']._serialized_end=1011
  _globals['_MEVNODETONODECALCULATIONRESPONSE']._serialized_start=1014
  _globals['_MEVNODETONODECALCULATIONRESPONSE']._serialized_end=1218
  _globals['_MEVNODETONODECALCULATIONRESPONSE_MEVANDVOLUMEPERCLOB']._serialized_start=1146
  _globals['_MEVNODETONODECALCULATIONRESPONSE_MEVANDVOLUMEPERCLOB']._serialized_end=1218
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONREQUEST']._serialized_start=1220
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONREQUEST']._serialized_end=1262
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_start=1265
  _globals['_QUERYEQUITYTIERLIMITCONFIGURATIONRESPONSE']._serialized_end=1397
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONREQUEST']._serialized_start=1399
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONREQUEST']._serialized_end=1440
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_start=1443
  _globals['_QUERYBLOCKRATELIMITCONFIGURATIONRESPONSE']._serialized_end=1572
  _globals['_QUERYSTATEFULORDERREQUEST']._serialized_start=1574
  _globals['_QUERYSTATEFULORDERREQUEST']._serialized_end=1653
  _globals['_QUERYSTATEFULORDERRESPONSE']._serialized_start=1656
  _globals['_QUERYSTATEFULORDERRESPONSE']._serialized_end=1798
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONREQUEST']._serialized_start=1800
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONREQUEST']._serialized_end=1839
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE']._serialized_start=1841
  _globals['_QUERYLIQUIDATIONSCONFIGURATIONRESPONSE']._serialized_end=1955
  _globals['_STREAMORDERBOOKUPDATESREQUEST']._serialized_start=1957
  _globals['_STREAMORDERBOOKUPDATESREQUEST']._serialized_end=2010
  _globals['_STREAMORDERBOOKUPDATESRESPONSE']._serialized_start=2013
  _globals['_STREAMORDERBOOKUPDATESRESPONSE']._serialized_end=2142
  _globals['_STREAMUPDATE']._serialized_start=2145
  _globals['_STREAMUPDATE']._serialized_end=2309
  _globals['_STREAMORDERBOOKUPDATE']._serialized_start=2311
  _globals['_STREAMORDERBOOKUPDATE']._serialized_end=2433
  _globals['_STREAMORDERBOOKFILL']._serialized_start=2436
  _globals['_STREAMORDERBOOKFILL']._serialized_end=2583
  _globals['_QUERY']._serialized_start=2586
  _globals['_QUERY']._serialized_end=3896
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/rewards/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.rewards import params_pb2 as dydxprotocol_dot_rewards_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/rewards/query.proto\x12\x14\x64ydxprotocol.rewards\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a!dydxprotocol/rewards/params.proto\"\x14\n\x12QueryParamsRequest\"I\n\x13QueryParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.rewards.ParamsB\x04\xc8\xde\x1f\x00\x32\x90\x01\n\x05Query\x12\x86\x01\n\x06Params\x12(.dydxprotocol.rewards.QueryParamsRequest\x1a).dydxprotocol.rewards.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/dydxprotocol/v4/rewards/paramsB;Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.rewards.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/dydxprotocol/v4/rewards/params'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=145
  _globals['_QUERYPARAMSREQUEST']._serialized_end=165
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=167
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=240
  _globals['_QUERY']._serialized_start=243
  _globals['_QUERY']._serialized_end=387
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/store/streaming/abci/grpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from v4_proto.cosmos.store.v1beta1 import listening_pb2 as cosmos_dot_store_dot_v1beta1_dot_listening__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/store/streaming/abci/grpc.proto\x12\x1b\x63osmos.store.streaming.abci\x1a\x1btendermint/abci/types.proto\x1a$cosmos/store/v1beta1/listening.proto\"\x85\x01\n\x1aListenFinalizeBlockRequest\x12\x32\n\x03req\x18\x01 \x01(\x0b\x32%.tendermint.abci.RequestFinalizeBlock\x12\x33\n\x03res\x18\x02 \x01(\x0b\x32&.tendermint.abci.ResponseFinalizeBlock\"\x1d\n\x1bListenFinalizeBlockResponse\"\x90\x01\n\x13ListenCommitRequest\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12,\n\x03res\x18\x02 \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommit\x12\x35\n\nchange_set\x18\x03 \x03(\x0b\x32!.cosmos.store.v1beta1.StoreKVPair\"\x16\n\x14ListenCommitResponse2\x95\x02\n\x13\x41\x42\x43IListenerService\x12\x88\x01\n\x13ListenFinalizeBlock\x12\x37.cosmos.store.streaming.abci.ListenFinalizeBlockRequest\x1a\x38.cosmos.store.streaming.abci.ListenFinalizeBlockResponse\x12s\n\x0cListenCommit\x12\x30.cosmos.store.streaming.abci.ListenCommitRequest\x1a\x31.cosmos.store.streaming.abci.ListenCommitResponseB#Z!cosmossdk.io/store/streaming/abcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.store.streaming.abci.grpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z!cosmossdk.io/store/streaming/abci'
  _globals['_LISTENFINALIZEBLOCKREQUEST']._serialized_start=139
  _globals['_LISTENFINALIZEBLOCKREQUEST']._serialized_end=272
  _globals['_LISTENFINALIZEBLOCKRESPONSE']._serialized_start=274
  _globals['_LISTENFINALIZEBLOCKRESPONSE']._serialized_end=303
  _globals['_LISTENCOMMITREQUEST']._serialized_start=306
  _globals['_LISTENCOMMITREQUEST']._serialized_end=450
  _globals['_LISTENCOMMITRESPONSE']._serialized_start=452
  _globals['_LISTENCOMMITRESPONSE']._serialized_end=474
  _globals['_ABCILISTENERSERVICE']._serialized_start=477
  _globals['_ABCILISTENERSERVICE']._serialized_end=754
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/query.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.vault.ParamsB\x04\xc8\xde\x1f\x00\"P\n\x11QueryVaultRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"\xc7\x01\n\x12QueryVaultResponse\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12\x43\n\rsubaccount_id\x18\x02 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06\x65quity\x18\x03 \x01(\x04\x12\x11\n\tinventory\x18\x04 \x01(\x04\x12\x14\n\x0ctotal_shares\x18\x05 \x01(\x04\"S\n\x15QueryAllVaultsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8d\x01\n\x16QueryAllVaultsResponse\x12\x36\n\x06vaults\x18\x01 \x03(\x0b\x32&.dydxprotocol.vault.QueryVaultResponse\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x92\x01\n\x17QueryOwnerSharesRequest\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"d\n\nOwnerShare\x12\'\n\x05owner\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12-\n\x06shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\"\x8d\x01\n\x18QueryOwnerSharesResponse\x12\x34\n\x0cowner_shares\x18\x01 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xbf\x04\n\x05Query\x12}\n\x06Params\x12&.dydxprotocol.vault.QueryParamsRequest\x1a\'.dydxprotocol.vault.QueryParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/dydxprotocol/vault/params\x12\x89\x01\n\x05Vault\x12%.dydxprotocol.vault.QueryVaultRequest\x1a&.dydxprotocol.vault.QueryVaultResponse\"1\x82\xd3\xe4\x93\x02+\x12)/dydxprotocol/vault/vault/{type}/{number}\x12\x85\x01\n\tAllVaults\x12).dydxprotocol.vault.QueryAllVaultsRequest\x1a*.dydxprotocol.vault.QueryAllVaultsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/dydxprotocol/vault/vault\x12\xa2\x01\n\x0bOwnerShares\x12+.dydxprotocol.vault.QueryOwnerSharesRequest\x1a,.dydxprotocol.vault.QueryOwnerSharesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/dydxprotocol/vault/owner_shares/{type}/{number}B9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_QUERYVAULTRESPONSE'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_OWNERSHARE'].fields_by_name['owner']._loaded_options = None
  _globals['_OWNERSHARE'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\034\022\032/dydxprotocol/vault/params'
  _globals['_QUERY'].methods_by_name['Vault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Vault']._serialized_options = b'\202\323\344\223\002+\022)/dydxprotocol/vault/vault/{type}/{number}'
  _globals['_QUERY'].methods_by_name['AllVaults']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllVaults']._serialized_options = b'\202\323\344\223\002\033\022\031/dydxprotocol/vault/vault'
  _globals['_QUERY'].methods_by_name['OwnerShares']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OwnerShares']._serialized_options = b'\202\323\344\223\0022\0220/dydxprotocol/vault/owner_shares/{type}/{number}'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=285
  _globals['_QUERYPARAMSREQUEST']._serialized_end=305
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=307
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=378
  _globals['_QUERYVAULTREQUEST']._serialized_start=380
  _globals['_QUERYVAULTREQUEST']._serialized_end=460
  _globals['_QUERYVAULTRESPONSE']._serialized_start=463
  _globals['_QUERYVAULTRESPONSE']._serialized_end=662
  _globals['_QUERYALLVAULTSREQUEST']._serialized_start=664
  _globals['_QUERYALLVAULTSREQUEST']._serialized_end=747
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_start=750
  _globals['_QUERYALLVAULTSRESPONSE']._serialized_end=891
  _globals['_QUERYOWNERSHARESREQUEST']._serialized_start=894
  _globals['_QUERYOWNERSHARESREQUEST']._serialized_end=1040
  _globals['_OWNERSHARE']._serialized_start=1042
  _globals['_OWNERSHARE']._serialized_end=1142
  _globals['_QUERYOWNERSHARESRESPONSE']._serialized_start=1145
  _globals['_QUERYOWNERSHARESRESPONSE']._serialized_end=1286
  _globals['_QUERY']._serialized_start=1289
  _globals['_QUERY']._serialized_end=1864
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as dydxprotocol_dot_indexer_dot_shared_dot_removal__reason__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_clob__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>dydxprotocol/indexer/off_chain_updates/off_chain_updates.proto\x12&dydxprotocol.indexer.off_chain_updates\x1a\x30\x64ydxprotocol/indexer/shared/removal_reason.proto\x1a+dydxprotocol/indexer/protocol/v1/clob.proto\"\xc5\x02\n\x0cOrderPlaceV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x12\x63\n\x10placement_status\x18\x02 \x01(\x0e\x32I.dydxprotocol.indexer.off_chain_updates.OrderPlaceV1.OrderPlacementStatus\"\x90\x01\n\x14OrderPlacementStatus\x12&\n\"ORDER_PLACEMENT_STATUS_UNSPECIFIED\x10\x00\x12-\n)ORDER_PLACEMENT_STATUS_BEST_EFFORT_OPENED\x10\x01\x12!\n\x1dORDER_PLACEMENT_STATUS_OPENED\x10\x02\"\xae\x03\n\rOrderRemoveV1\x12J\n\x10removed_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.dydxprotocol.indexer.shared.OrderRemovalReason\x12`\n\x0eremoval_status\x18\x03 \x01(\x0e\x32H.dydxprotocol.indexer.off_chain_updates.OrderRemoveV1.OrderRemovalStatus\"\xad\x01\n\x12OrderRemovalStatus\x12$\n ORDER_REMOVAL_STATUS_UNSPECIFIED\x10\x00\x12-\n)ORDER_REMOVAL_STATUS_BEST_EFFORT_CANCELED\x10\x01\x12!\n\x1dORDER_REMOVAL_STATUS_CANCELED\x10\x02\x12\x1f\n\x1bORDER_REMOVAL_STATUS_FILLED\x10\x03\"r\n\rOrderUpdateV1\x12\x42\n\x08order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12\x1d\n\x15total_filled_quantums\x18\x02 \x01(\x04\"\x8f\x02\n\x10OffChainUpdateV1\x12K\n\x0border_place\x18\x01 \x01(\x0b\x32\x34.dydxprotocol.indexer.off_chain_updates.OrderPlaceV1H\x00\x12M\n\x0corder_remove\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.off_chain_updates.OrderRemoveV1H\x00\x12M\n\x0corder_update\x18\x03 \x01(\x0b\x32\x35.dydxprotocol.indexer.off_chain_updates.OrderUpdateV1H\x00\x42\x10\n\x0eupdate_messageBKZIgithub.com/dydxprotocol/v4-chain/protocol/indexer/off_chain_updates/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.off_chain_updates.off_chain_updates_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZIgithub.com/dydxprotocol/v4-chain/protocol/indexer/off_chain_updates/types'
  _globals['_ORDERPLACEV1']._serialized_start=202
  _globals['_ORDERPLACEV1']._serialized_end=527
  _globals['_ORDERPLACEV1_ORDERPLACEMENTSTATUS']._serialized_start=383
  _globals['_ORDERPLACEV1_ORDERPLACEMENTSTATUS']._serialized_end=527
  _globals['_ORDERREMOVEV1']._serialized_start=530
  _globals['_ORDERREMOVEV1']._serialized_end=960
  _globals['_ORDERREMOVEV1_ORDERREMOVALSTATUS']._serialized_start=787
  _globals['_ORDERREMOVEV1_ORDERREMOVALSTATUS']._serialized_end=960
  _globals['_ORDERUPDATEV1']._serialized_start=962
  _globals['_ORDERUPDATEV1']._serialized_end=1076
  _globals['_OFFCHAINUPDATEV1']._serialized_start=1079
  _globals['_OFFCHAINUPDATEV1']._serialized_end=1350
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BridgeEvent(_message.Message):
    __slots__ = ("id", "coin", "address", "eth_block_height")
    ID_FIELD_NUMBER: _ClassVar[int]
    COIN_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ETH_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    id: int
    coin: _coin_pb2.Coin
    address: str
    eth_block_height: int
    def __init__(self, id: _Optional[int] = ..., coin: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., address: _Optional[str] = ..., eth_block_height: _Optional[int] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.bank.v1beta1 import query_pb2 as cosmos_dot_bank_dot_v1beta1_dot_query__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/bank/v1beta1/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Balance = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/Balance',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
                _registered_method=True)
        self.AllBalances = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/AllBalances',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString,
                _registered_method=True)
        self.SpendableBalances = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SpendableBalances',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString,
                _registered_method=True)
        self.SpendableBalanceByDenom = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SpendableBalanceByDenom',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomResponse.FromString,
                _registered_method=True)
        self.TotalSupply = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/TotalSupply',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString,
                _registered_method=True)
        self.SupplyOf = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SupplyOf',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/Params',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.DenomMetadata = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomMetadata',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString,
                _registered_method=True)
        self.DenomMetadataByQueryString = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomMetadataByQueryString',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringResponse.FromString,
                _registered_method=True)
        self.DenomsMetadata = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomsMetadata',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString,
                _registered_method=True)
        self.DenomOwners = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomOwners',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersResponse.FromString,
                _registered_method=True)
        self.SendEnabled = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SendEnabled',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Balance(self, request, context):
        """Balance queries the balance of a single coin for a single account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllBalances(self, request, context):
        """AllBalances queries the balance of all coins for a single account.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpendableBalances(self, request, context):
        """SpendableBalances queries the spendable balance of all coins for a single
        account.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpendableBalanceByDenom(self, request, context):
        """SpendableBalanceByDenom queries the spendable balance of a single denom for
        a single account.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalSupply(self, request, context):
        """TotalSupply queries the total supply of all coins.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SupplyOf(self, request, context):
        """SupplyOf queries the supply of a single coin.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries the parameters of x/bank module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomMetadata(self, request, context):
        """DenomsMetadata queries the client metadata of a given coin denomination.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomMetadataByQueryString(self, request, context):
        """DenomsMetadata queries the client metadata of a given coin denomination.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomsMetadata(self, request, context):
        """DenomsMetadata queries the client metadata for all registered coin
        denominations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomOwners(self, request, context):
        """DenomOwners queries for all account addresses that own a particular token
        denomination.

        When called from another module, this query might consume a high amount of
        gas if the pagination field is incorrectly set.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendEnabled(self, request, context):
        """SendEnabled queries for SendEnabled entries.

        This query only returns denominations that have specific SendEnabled settings.
        Any denomination that does not have a specific setting will use the default
        params.default_send_enabled, and will not be returned by this query.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.SerializeToString,
            ),
            'AllBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.AllBalances,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.SerializeToString,
            ),
            'SpendableBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.SpendableBalances,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.SerializeToString,
            ),
            'SpendableBalanceByDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.SpendableBalanceByDenom,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomResponse.SerializeToString,
            ),
            'TotalSupply': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalSupply,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.SerializeToString,
            ),
            'SupplyOf': grpc.unary_unary_rpc_method_handler(
                    servicer.SupplyOf,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'DenomMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomMetadata,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.SerializeToString,
            ),
            'DenomMetadataByQueryString': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomMetadataByQueryString,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringResponse.SerializeToString,
            ),
            'DenomsMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomsMetadata,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.SerializeToString,
            ),
            'DenomOwners': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomOwners,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersResponse.SerializeToString,
            ),
            'SendEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.SendEnabled,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.bank.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.bank.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/Balance',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/AllBalances',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SpendableBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/SpendableBalances',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SpendableBalanceByDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/SpendableBalanceByDenom',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalanceByDenomResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TotalSupply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/TotalSupply',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SupplyOf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/SupplyOf',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/Params',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/DenomMetadata',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomMetadataByQueryString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/DenomMetadataByQueryString',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataByQueryStringResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomsMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/DenomsMetadata',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DenomOwners(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/DenomOwners',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomOwnersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SendEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Query/SendEnabled',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySendEnabledResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.dydxprotocol.delaymsg import delayed_message_pb2 as dydxprotocol_dot_delaymsg_dot_delayed__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/delaymsg/genesis.proto\x12\x15\x64ydxprotocol.delaymsg\x1a+dydxprotocol/delaymsg/delayed_message.proto\"p\n\x0cGenesisState\x12?\n\x10\x64\x65layed_messages\x18\x01 \x03(\x0b\x32%.dydxprotocol.delaymsg.DelayedMessage\x12\x1f\n\x17next_delayed_message_id\x18\x02 \x01(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_GENESISSTATE']._serialized_start=107
  _globals['_GENESISSTATE']._serialized_end=219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/govplus/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/govplus/tx.proto\x12\x14\x64ydxprotocol.govplus\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"\xe6\x02\n\x11MsgSlashValidator\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12<\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12\x19\n\x11infraction_height\x18\x03 \x01(\r\x12m\n\x1btokens_at_infraction_height\x18\x04 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12L\n\x0cslash_factor\x18\x05 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgSlashValidatorResponse2q\n\x03Msg\x12j\n\x0eSlashValidator\x12\'.dydxprotocol.govplus.MsgSlashValidator\x1a/.dydxprotocol.govplus.MsgSlashValidatorResponseB;Z9github.com/dydxprotocol/v4-chain/protocol/x/govplus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.govplus.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/govplus/types'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['tokens_at_infraction_height']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['tokens_at_infraction_height']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['slash_factor']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR'].fields_by_name['slash_factor']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_MSGSLASHVALIDATOR']._loaded_options = None
  _globals['_MSGSLASHVALIDATOR']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGSLASHVALIDATOR']._serialized_start=149
  _globals['_MSGSLASHVALIDATOR']._serialized_end=507
  _globals['_MSGSLASHVALIDATORRESPONSE']._serialized_start=509
  _globals['_MSGSLASHVALIDATORRESPONSE']._serialized_end=536
  _globals['_MSG']._serialized_start=538
  _globals['_MSG']._serialized_end=651
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VoteOption(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VOTE_OPTION_UNSPECIFIED: _ClassVar[VoteOption]
    VOTE_OPTION_YES: _ClassVar[VoteOption]
    VOTE_OPTION_ABSTAIN: _ClassVar[VoteOption]
    VOTE_OPTION_NO: _ClassVar[VoteOption]
    VOTE_OPTION_NO_WITH_VETO: _ClassVar[VoteOption]

class ProposalStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROPOSAL_STATUS_UNSPECIFIED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_SUBMITTED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_ACCEPTED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_REJECTED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_ABORTED: _ClassVar[ProposalStatus]
    PROPOSAL_STATUS_WITHDRAWN: _ClassVar[ProposalStatus]

class ProposalExecutorResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PROPOSAL_EXECUTOR_RESULT_UNSPECIFIED: _ClassVar[ProposalExecutorResult]
    PROPOSAL_EXECUTOR_RESULT_NOT_RUN: _ClassVar[ProposalExecutorResult]
    PROPOSAL_EXECUTOR_RESULT_SUCCESS: _ClassVar[ProposalExecutorResult]
    PROPOSAL_EXECUTOR_RESULT_FAILURE: _ClassVar[ProposalExecutorResult]
VOTE_OPTION_UNSPECIFIED: VoteOption
VOTE_OPTION_YES: VoteOption
VOTE_OPTION_ABSTAIN: VoteOption
VOTE_OPTION_NO: VoteOption
VOTE_OPTION_NO_WITH_VETO: VoteOption
PROPOSAL_STATUS_UNSPECIFIED: ProposalStatus
PROPOSAL_STATUS_SUBMITTED: ProposalStatus
PROPOSAL_STATUS_ACCEPTED: ProposalStatus
PROPOSAL_STATUS_REJECTED: ProposalStatus
PROPOSAL_STATUS_ABORTED: ProposalStatus
PROPOSAL_STATUS_WITHDRAWN: ProposalStatus
PROPOSAL_EXECUTOR_RESULT_UNSPECIFIED: ProposalExecutorResult
PROPOSAL_EXECUTOR_RESULT_NOT_RUN: ProposalExecutorResult
PROPOSAL_EXECUTOR_RESULT_SUCCESS: ProposalExecutorResult
PROPOSAL_EXECUTOR_RESULT_FAILURE: ProposalExecutorResult

class Member(_message.Message):
    __slots__ = ("address", "weight", "metadata", "added_at")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ADDED_AT_FIELD_NUMBER: _ClassVar[int]
    address: str
    weight: str
    metadata: str
    added_at: _timestamp_pb2.Timestamp
    def __init__(self, address: _Optional[str] = ..., weight: _Optional[str] = ..., metadata: _Optional[str] = ..., added_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MemberRequest(_message.Message):
    __slots__ = ("address", "weight", "metadata")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    address: str
    weight: str
    metadata: str
    def __init__(self, address: _Optional[str] = ..., weight: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...

class ThresholdDecisionPolicy(_message.Message):
    __slots__ = ("threshold", "windows")
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    WINDOWS_FIELD_NUMBER: _ClassVar[int]
    threshold: str
    windows: DecisionPolicyWindows
    def __init__(self, threshold: _Optional[str] = ..., windows: _Optional[_Union[DecisionPolicyWindows, _Mapping]] = ...) -> None: ...

class PercentageDecisionPolicy(_message.Message):
    __slots__ = ("percentage", "windows")
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    WINDOWS_FIELD_NUMBER: _ClassVar[int]
    percentage: str
    windows: DecisionPolicyWindows
    def __init__(self, percentage: _Optional[str] = ..., windows: _Optional[_Union[DecisionPolicyWindows, _Mapping]] = ...) -> None: ...

class DecisionPolicyWindows(_message.Message):
    __slots__ = ("voting_period", "min_execution_period")
    VOTING_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MIN_EXECUTION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    voting_period: _duration_pb2.Duration
    min_execution_period: _duration_pb2.Duration
    def __init__(self, voting_period: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., min_execution_period: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class GroupInfo(_message.Message):
    __slots__ = ("id", "admin", "metadata", "version", "total_weight", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    TOTAL_WEIGHT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: int
    admin: str
    metadata: str
    version: int
    total_weight: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[int] = ..., admin: _Optional[str] = ..., metadata: _Optional[str] = ..., version: _Optional[int] = ..., total_weight: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GroupMember(_message.Message):
    __slots__ = ("group_id", "member")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    member: Member
    def __init__(self, group_id: _Optional[int] = ..., member: _Optional[_Union[Member, _Mapping]] = ...) -> None: ...

class GroupPolicyInfo(_message.Message):
    __slots__ = ("address", "group_id", "admin", "metadata", "version", "decision_policy", "created_at")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DECISION_POLICY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    address: str
    group_id: int
    admin: str
    metadata: str
    version: int
    decision_policy: _any_pb2.Any
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, address: _Optional[str] = ..., group_id: _Optional[int] = ..., admin: _Optional[str] = ..., metadata: _Optional[str] = ..., version: _Optional[int] = ..., decision_policy: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Proposal(_message.Message):
    __slots__ = ("id", "group_policy_address", "metadata", "proposers", "submit_time", "group_version", "group_policy_version", "status", "final_tally_result", "voting_period_end", "executor_result", "messages", "title", "summary")
    ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PROPOSERS_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_TIME_FIELD_NUMBER: _ClassVar[int]
    GROUP_VERSION_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_VERSION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    FINAL_TALLY_RESULT_FIELD_NUMBER: _ClassVar[int]
    VOTING_PERIOD_END_FIELD_NUMBER: _ClassVar[int]
    EXECUTOR_RESULT_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    id: int
    group_policy_address: str
    metadata: str
    proposers: _containers.RepeatedScalarFieldContainer[str]
    submit_time: _timestamp_pb2.Timestamp
    group_version: int
    group_policy_version: int
    status: ProposalStatus
    final_tally_result: TallyResult
    voting_period_end: _timestamp_pb2.Timestamp
    executor_result: ProposalExecutorResult
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    title: str
    summary: str
    def __init__(self, id: _Optional[int] = ..., group_policy_address: _Optional[str] = ..., metadata: _Optional[str] = ..., proposers: _Optional[_Iterable[str]] = ..., submit_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., group_version: _Optional[int] = ..., group_policy_version: _Optional[int] = ..., status: _Optional[_Union[ProposalStatus, str]] = ..., final_tally_result: _Optional[_Union[TallyResult, _Mapping]] = ..., voting_period_end: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., executor_result: _Optional[_Union[ProposalExecutorResult, str]] = ..., messages: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., title: _Optional[str] = ..., summary: _Optional[str] = ...) -> None: ...

class TallyResult(_message.Message):
    __slots__ = ("yes_count", "abstain_count", "no_count", "no_with_veto_count")
    YES_COUNT_FIELD_NUMBER: _ClassVar[int]
    ABSTAIN_COUNT_FIELD_NUMBER: _ClassVar[int]
    NO_COUNT_FIELD_NUMBER: _ClassVar[int]
    NO_WITH_VETO_COUNT_FIELD_NUMBER: _ClassVar[int]
    yes_count: str
    abstain_count: str
    no_count: str
    no_with_veto_count: str
    def __init__(self, yes_count: _Optional[str] = ..., abstain_count: _Optional[str] = ..., no_count: _Optional[str] = ..., no_with_veto_count: _Optional[str] = ...) -> None: ...

class Vote(_message.Message):
    __slots__ = ("proposal_id", "voter", "option", "metadata", "submit_time")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SUBMIT_TIME_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    option: VoteOption
    metadata: str
    submit_time: _timestamp_pb2.Timestamp
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ..., option: _Optional[_Union[VoteOption, str]] = ..., metadata: _Optional[str] = ..., submit_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterChangeProposal(_message.Message):
    __slots__ = ("title", "description", "changes")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CHANGES_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    changes: _containers.RepeatedCompositeFieldContainer[ParamChange]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., changes: _Optional[_Iterable[_Union[ParamChange, _Mapping]]] = ...) -> None: ...

class ParamChange(_message.Message):
    __slots__ = ("subspace", "key", "value")
    SUBSPACE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    subspace: str
    key: str
    value: str
    def __init__(self, subspace: _Optional[str] = ..., key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/event.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/event.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\"x\n\nEventGrant\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12)\n\x07granter\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"y\n\x0b\x45ventRevoke\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12)\n\x07granter\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12)\n\x07grantee\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringB&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _globals['_EVENTGRANT'].fields_by_name['granter']._loaded_options = None
  _globals['_EVENTGRANT'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTGRANT'].fields_by_name['grantee']._loaded_options = None
  _globals['_EVENTGRANT'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTREVOKE'].fields_by_name['granter']._loaded_options = None
  _globals['_EVENTREVOKE'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTREVOKE'].fields_by_name['grantee']._loaded_options = None
  _globals['_EVENTREVOKE'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTGRANT']._serialized_start=85
  _globals['_EVENTGRANT']._serialized_end=205
  _globals['_EVENTREVOKE']._serialized_start=207
  _globals['_EVENTREVOKE']._serialized_end=328
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from v4_proto.dydxprotocol.vault import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as _vault_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryVaultRequest(_message.Message):
    __slots__ = ("type", "number")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    type: _vault_pb2.VaultType
    number: int
    def __init__(self, type: _Optional[_Union[_vault_pb2.VaultType, str]] = ..., number: _Optional[int] = ...) -> None: ...

class QueryVaultResponse(_message.Message):
    __slots__ = ("vault_id", "subaccount_id", "equity", "inventory", "total_shares")
    VAULT_ID_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    EQUITY_FIELD_NUMBER: _ClassVar[int]
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SHARES_FIELD_NUMBER: _ClassVar[int]
    vault_id: _vault_pb2.VaultId
    subaccount_id: _subaccount_pb2.SubaccountId
    equity: int
    inventory: int
    total_shares: int
    def __init__(self, vault_id: _Optional[_Union[_vault_pb2.VaultId, _Mapping]] = ..., subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., equity: _Optional[int] = ..., inventory: _Optional[int] = ..., total_shares: _Optional[int] = ...) -> None: ...

class QueryAllVaultsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllVaultsResponse(_message.Message):
    __slots__ = ("vaults", "pagination")
    VAULTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    vaults: _containers.RepeatedCompositeFieldContainer[QueryVaultResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, vaults: _Optional[_Iterable[_Union[QueryVaultResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryOwnerSharesRequest(_message.Message):
    __slots__ = ("type", "number", "pagination")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    type: _vault_pb2.VaultType
    number: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, type: _Optional[_Union[_vault_pb2.VaultType, str]] = ..., number: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class OwnerShare(_message.Message):
    __slots__ = ("owner", "shares")
    OWNER_FIELD_NUMBER: _ClassVar[int]
    SHARES_FIELD_NUMBER: _ClassVar[int]
    owner: str
    shares: _vault_pb2.NumShares
    def __init__(self, owner: _Optional[str] = ..., shares: _Optional[_Union[_vault_pb2.NumShares, _Mapping]] = ...) -> None: ...

class QueryOwnerSharesResponse(_message.Message):
    __slots__ = ("owner_shares", "pagination")
    OWNER_SHARES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    owner_shares: _containers.RepeatedCompositeFieldContainer[OwnerShare]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, owner_shares: _Optional[_Iterable[_Union[OwnerShare, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.group.v1 import types_pb2 as _types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EventCreateGroup(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    def __init__(self, group_id: _Optional[int] = ...) -> None: ...

class EventUpdateGroup(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    def __init__(self, group_id: _Optional[int] = ...) -> None: ...

class EventCreateGroupPolicy(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class EventUpdateGroupPolicy(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class EventSubmitProposal(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class EventWithdrawProposal(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class EventVote(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class EventExec(_message.Message):
    __slots__ = ("proposal_id", "result", "logs")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    result: _types_pb2.ProposalExecutorResult
    logs: str
    def __init__(self, proposal_id: _Optional[int] = ..., result: _Optional[_Union[_types_pb2.ProposalExecutorResult, str]] = ..., logs: _Optional[str] = ...) -> None: ...

class EventLeaveGroup(_message.Message):
    __slots__ = ("group_id", "address")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    address: str
    def __init__(self, group_id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class EventProposalPruned(_message.Message):
    __slots__ = ("proposal_id", "status", "tally_result")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TALLY_RESULT_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    status: _types_pb2.ProposalStatus
    tally_result: _types_pb2.TallyResult
    def __init__(self, proposal_id: _Optional[int] = ..., status: _Optional[_Union[_types_pb2.ProposalStatus, str]] = ..., tally_result: _Optional[_Union[_types_pb2.TallyResult, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/rewards/reward_share.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'dydxprotocol/rewards/reward_share.proto\x12\x14\x64ydxprotocol.rewards\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\x92\x01\n\x0bRewardShare\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12X\n\x06weight\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableIntB;Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.rewards.reward_share_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/types'
  _globals['_REWARDSHARE'].fields_by_name['address']._loaded_options = None
  _globals['_REWARDSHARE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_REWARDSHARE'].fields_by_name['weight']._loaded_options = None
  _globals['_REWARDSHARE'].fields_by_name['weight']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_REWARDSHARE']._serialized_start=115
  _globals['_REWARDSHARE']._serialized_end=261
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.stats import params_pb2 as _params_pb2
from v4_proto.dydxprotocol.stats import stats_pb2 as _stats_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryStatsMetadataRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryStatsMetadataResponse(_message.Message):
    __slots__ = ("metadata",)
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _stats_pb2.StatsMetadata
    def __init__(self, metadata: _Optional[_Union[_stats_pb2.StatsMetadata, _Mapping]] = ...) -> None: ...

class QueryGlobalStatsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryGlobalStatsResponse(_message.Message):
    __slots__ = ("stats",)
    STATS_FIELD_NUMBER: _ClassVar[int]
    stats: _stats_pb2.GlobalStats
    def __init__(self, stats: _Optional[_Union[_stats_pb2.GlobalStats, _Mapping]] = ...) -> None: ...

class QueryUserStatsRequest(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: str
    def __init__(self, user: _Optional[str] = ...) -> None: ...

class QueryUserStatsResponse(_message.Message):
    __slots__ = ("stats",)
    STATS_FIELD_NUMBER: _ClassVar[int]
    stats: _stats_pb2.UserStats
    def __init__(self, stats: _Optional[_Union[_stats_pb2.UserStats, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/epochs/epoch_info.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$dydxprotocol/epochs/epoch_info.proto\x12\x13\x64ydxprotocol.epochs\"\xb0\x01\n\tEpochInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnext_tick\x18\x02 \x01(\r\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\x12\x15\n\rcurrent_epoch\x18\x04 \x01(\r\x12!\n\x19\x63urrent_epoch_start_block\x18\x05 \x01(\r\x12\x16\n\x0eis_initialized\x18\x06 \x01(\x08\x12\x1e\n\x16\x66\x61st_forward_next_tick\x18\x07 \x01(\x08\x42:Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.epochs.epoch_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/epochs/types'
  _globals['_EPOCHINFO']._serialized_start=62
  _globals['_EPOCHINFO']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/group/v1/genesis.proto\x12\x0f\x63osmos.group.v1\x1a\x1b\x63osmos/group/v1/types.proto\"\xc0\x02\n\x0cGenesisState\x12\x11\n\tgroup_seq\x18\x01 \x01(\x04\x12*\n\x06groups\x18\x02 \x03(\x0b\x32\x1a.cosmos.group.v1.GroupInfo\x12\x33\n\rgroup_members\x18\x03 \x03(\x0b\x32\x1c.cosmos.group.v1.GroupMember\x12\x18\n\x10group_policy_seq\x18\x04 \x01(\x04\x12\x38\n\x0egroup_policies\x18\x05 \x03(\x0b\x32 .cosmos.group.v1.GroupPolicyInfo\x12\x14\n\x0cproposal_seq\x18\x06 \x01(\x04\x12,\n\tproposals\x18\x07 \x03(\x0b\x32\x19.cosmos.group.v1.Proposal\x12$\n\x05votes\x18\x08 \x03(\x0b\x32\x15.cosmos.group.v1.VoteB&Z$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/group'
  _globals['_GENESISSTATE']._serialized_start=80
  _globals['_GENESISSTATE']._serialized_end=400
# @@protoc_insertion_point(module_scope)



from google.protobuf import any_pb2 as _any_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Plan(_message.Message):
    __slots__ = ("name", "time", "height", "info", "upgraded_client_state")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    INFO_FIELD_NUMBER: _ClassVar[int]
    UPGRADED_CLIENT_STATE_FIELD_NUMBER: _ClassVar[int]
    name: str
    time: _timestamp_pb2.Timestamp
    height: int
    info: str
    upgraded_client_state: _any_pb2.Any
    def __init__(self, name: _Optional[str] = ..., time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., height: _Optional[int] = ..., info: _Optional[str] = ..., upgraded_client_state: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class SoftwareUpgradeProposal(_message.Message):
    __slots__ = ("title", "description", "plan")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    plan: Plan
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., plan: _Optional[_Union[Plan, _Mapping]] = ...) -> None: ...

class CancelSoftwareUpgradeProposal(_message.Message):
    __slots__ = ("title", "description")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class ModuleVersion(_message.Message):
    __slots__ = ("name", "version")
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: int
    def __init__(self, name: _Optional[str] = ..., version: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Asset(_message.Message):
    __slots__ = ("id", "symbol", "denom", "denom_exponent", "has_market", "market_id", "atomic_resolution")
    ID_FIELD_NUMBER: _ClassVar[int]
    SYMBOL_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    DENOM_EXPONENT_FIELD_NUMBER: _ClassVar[int]
    HAS_MARKET_FIELD_NUMBER: _ClassVar[int]
    MARKET_ID_FIELD_NUMBER: _ClassVar[int]
    ATOMIC_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    id: int
    symbol: str
    denom: str
    denom_exponent: int
    has_market: bool
    market_id: int
    atomic_resolution: int
    def __init__(self, id: _Optional[int] = ..., symbol: _Optional[str] = ..., denom: _Optional[str] = ..., denom_exponent: _Optional[int] = ..., has_market: bool = ..., market_id: _Optional[int] = ..., atomic_resolution: _Optional[int] = ...) -> None: ...
